Learn R Programming

qicharts (version 0.4.1)

paretochart: Pareto chart

Description

Creates a pareto chart from a categorical variable

Usage

paretochart(x, main, ylab = "Frequency", xlab = "", cumperc.by = 20,
  cex = 0.8, ...)

Arguments

x
Categorical vector to be plotted
main
Plot title
ylab
Label on first (left) y axis
xlab
Label on x axis
cumperc.by
Grid interval
cex
Number indicating the amount by which text and symbols should be magnified.
...
Further arguments to plot function

Value

  • A table of frequencies and percentages from the pareto analysis

Examples

Run this code
x <- rep(LETTERS[1:9], c(200, 100, 50, 25, 12, 6, 3, 2, 1))
paretochart(x)

Run the code above in your browser using DataLab