Learn R Programming

qicharts (version 0.4.3)

plot.tcc: Plot trellis control chart

Description

Creates a plot of a tcc object

Usage

## S3 method for class 'tcc':
plot(x, y = NULL, cex = 1, pex = 1, ylim = NULL,
  dec = 2, date.format = "\%Y-\%m-\%d", flip = FALSE, dots.only = FALSE,
  ...)

Arguments

x
List object returned from the tcc() function.
y
Ignored. Included for compatibility with generic plot function.
cex
Number indicating the amount by which text should be magnified.
pex
Number indicating the amount by which plotting symbols should be magnified.
ylim
Range of y axis.
dec
Number of decimals on center and control line labels.
date.format
Date format of x axis labels. See ?strftime for date formats.
flip
Logical. If TRUE rotates the plot 90 degrees.
dots.only
Logical value. If TRUE, data points are not connected by lines and runs analysis is not performed. Useful for comparison and funnel plots.
...
Further arguments to plot function.

Value

  • Creates a tcc plot.

Examples

Run this code
p <- tcc(rnorm(24))
plot(p)

Run the code above in your browser using DataLab